.. :changelog:

History
-------

1.1 (2013-11-22)
++++++++++++++++++

* Add history of uploads.
* Track uploaded timestamp.
* Support spidering pypi links to other sites.
* Improve sort order in UI.

1.0 (2013-11-19)
++++++++++++++++++

* Initial version.
